import { 
  select, 
  csv , 
  scaleTime, 
  scaleLinear,
  extent, 
  scalePoint, 
  axisLeft,
  axisBottom,   
} from 'd3'; 

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data => {
  const title = 'Week in San Fran';
  
  const xValue = d => d.timestamp;
  const xAxisLabel = 'Time';
  
  const yValue = d => d.temperature;
  const yAxisLabel = 'Temperature';
  
 //const margin = { top: 50, right: 40, bottom: 90, left: 150};
  const margin = { top: 60, right: 40, bottom: 88, left: 150};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 6; 

  
  
        
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  // scale Band is for the height of the bar charts
  const yScale = scaleLinear() 
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
		.nice();
  
    
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
	const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  //yAxis(g.append('g'));
const yAxisG =  g.append('g')
	yAxisG.call(yAxis)
  			.selectAll('.domain')  // .tick line removes the y axis lines
  			.remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.attr('x', -innerHeight/2)
  	.attr('y', -60)
  	.attr('transform', `rotate(-90)`)
    .style('text-anchor', 'middle')
    .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();  // .tick line removes the y axis lines
  		
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.attr('x', innerWidth/2)
  	.attr('y', 75)
    .text(xAxisLabel);
  
    
  g.selectAll('circle').data(data) // data join of rect elements and data, which is the csv
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx',  d => xScale(xValue(d)))
  		.attr('r', circleRadius);
  
	g.append('text')
  	.attr('class', 'title')
  	.attr('y', -10)
  	.text(title);



}; 

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
  .then(data => {
    data.forEach(d => { // parsing code here 
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
    render(data);
  });